include("sound/utils.nut")


/*
  Add music files below.
  The second parameter is loop start time in seconds.
  You can use fractional values for precision or -1 to disable looping.
  Loop end is always the end of the music.
*/

music <-
{
  level_one = load_music("sound/music/level-one.ogg", 0)
  title = load_music("sound/music/title.ogg", 0)
  upgrade_screen = load_music("sound/music/upgrade-music.ogg", 0)
}

music_volume <-
{
  level_one      = 1.0
  title          = 1.0
  upgrade_screen = 1.0
}

global_music_volume <- 0.5


/*
  Here are the events the game produces.
  Not all of them need sounds (some can just control music, for example).

  You can assign the following functions to them:

  S("filename", max, volume)
    Play single sample.
    Parameters (max and volume are optional):
      filename - relative to the "sounds" folder and has default .wav extension
      max - maximum channels for this sound
        when out of channels, the new sound will replace the oldest channel
        default is 1
      volume - sound volume in 0..1 range, default is 1 (full)

  R(list, params)
    Play random sample from the list.
    Parameters (params one is optional, see above for defaults):
      list can be:
        Just a quoted string of space-separated file names.
        [item1 item2 ...] where each item is string or S(...) (see above)
      params is used to set max/volume for all items
    Example:
      hero_shoot=R(["shot1" "shot2" "shot123"], { max=5, volume=1 })
    or
      hero_shoot=R("shot1 shot2", { max=3 })
    or
      hero_jump=R([S("jump1", 1, 0.5) "jump2" S("jump3", 2, 0.7)])

  START_MUSIC(name, fade_time_ms)
    Start music, fading out the currently playing one.
    Parameters:
      name must be the same as in "music" list above.
      fade_time_ms is optional and defaults to 200 milliseconds.

  STOP_MUSIC(fade_time_ms)
    Fade out and stop current music, but don't start a new one.
    fade_time_ms is optional and defaults to 200 milliseconds.

  SEQ(item1, item2, ...)
    Perform multiple actions.
    If you want to play sound, it should be the last one.
*/

events <-
{
  hero_shoot=R("BulletShot", { max=5, volume=1 })
  hero_jump=S("Jump", 2, 1)
  hero_hurt=S("PlayerHurt", 5)

  hero_dead=S("hero dead")
  game_over=NONE

  enemy_spots_hero=S("Enemy Spots Hero", 2, 1)
  enemy_hurt=NONE
  enemy_dead=R(["Explosion1" "Explosion2"])

  barrel_explode=R(["BigExplosion1"])

  bonus_heart=S("bonus-heart")
  bonus_up   =S("bonus-up")

  bullet_destroys_wall=R(["Hit Destructible1" "Hit Destructible2" "Hit Destructible3" "Hit Destructible4"])
  bullet_hits_indestructible=R(["Hit Indestructible1" "Hit Indestructible2"])

  // fade out music in 100 ms and play sound
  level_up_elevator=SEQ(STOP_MUSIC(500), S("Elevator Music"))

  upgrade_screen=START_MUSIC("upgrade_screen")
  upgrade_plus=S("upgrade plus")
  upgrade_minus=S("upgrade minus")
  upgrade_accept=SEQ(STOP_MUSIC(500), S("upgrade plus"))

  //start_level=NONE
  start_level=START_MUSIC("level_one") // to switch the music on

  title_screen   =START_MUSIC("title")
  end_demo_screen=START_MUSIC("title")
  new_game=S("upgrade plus")

  boss_part_damaged=S("hero dead")
  boss_part_explode=R(["BigExplosion1"])
  boss_dead=S("Elevator Music")
  boss1_activated=S("hero dead")
  boss1_shoot=S("upgrade minus", 1, 0.25)
  boss1_drop_bomb=S("upgrade plus", 1, 0.5)
  boss1_dying=S("boss1-death")
}
